- rwl
a data.frame with series as columns and years as rows
such as that produced by read.rwl.
- series
a numeric or character vector. Usually a
tree-ring series. If the length of the value is 1, the
corresponding column of rwl is selected (by name or
position) as the series and ignored when building the master
chronology. Otherwise, the value must be numeric.
- series.yrs
a numeric vector giving the years of
series. Defaults to
as.numeric(names(series)). Ignored if
series is an index to a column of rwl.
- seg.length
an even integral value giving length of segments in
years (e.g., 20, 50, 100 years).
- bin.floor
a non-negative integral value giving the base for
locating the first segment (e.g., 1600, 1700, 1800
AD). Typically 0, 10, 50, 100, etc.
- n
NULL or an integral value giving the filter length
for the hanning filter used for removal of low
frequency variation.
- nyrs
NULL or a number greater than zero. If not
NULL, each series is divided by a smoothing spline with this
rigidity (see caps) to remove low-frequency variation,
as detrend does with method = "Spline". A value
of 1 or less is taken as a proportion of each series' length.
Unlike the hanning filter, the spline removes no years
from the ends of a series. Cannot be combined with n.
- prewhiten
logical flag. If TRUE each series is
whitened using ar.
- ar.order.max
NULL or a positive integer giving the
maximum order of the ar model used to prewhiten.
Prewhitening removes as many years from the start of each series as
the order of the model. If NULL, the order is chosen by AIC
up to the ar default, which on long series can be 20
or more. Requires prewhiten = TRUE.
- biweight
logical flag. If TRUE then a robust
mean is calculated using tbrm.
- pcrit
a number between 0 and 1 giving the critical value for the
correlation test.
- lag.max
an integral value giving the maximum lag at which to
calculate the ccf.
- make.plot
logical flag indicating whether to make a
plot.
- floor.plus1
logical flag. If TRUE, one year is
added to the base location of the first segment (e.g., 1601, 1701,
1801 AD).
- series.x
logical flag indicating whether to make the series
the x argument to ccf. See Details.
- ...
other arguments passed to plot.