Learn R Programming

dplR (version 1.5.7)

glk: Calculate Gleichläufigkeit{Gleichlaeufigkeit}

Description

This function calculates the matrix of Gleichläufigkeit{Gleichlaeufigkeit} for a given set of tree-ring records.

Usage

glk(x)

Arguments

x
a data.frame of tree-ring data with records in columns, and years as rows.

Value

  • A matrix with the Gleichläufigkeit{Gleichlaeufigkeit} for all possible combinations of records. If two curves have less than 3 years of overlap, Gleichläufigkeit{Gleichlaeufigkeit} cannot be computed, and NA is returned.

Details

Gleichläufigkeit{Gleichlaeufigkeit} is a classical agreement test based on sign tests (Eckstein and Bauch, 1969). This function implements Gleichläufigkeit{Gleichlaeufigkeit} as the pairwise comparison of all records in data set, and thus returns a matrix whose upper triangle reports the Gleichläufigkeit{Gleichlaeufigkeit} of each possible combination of records. The global Gleichläufigkeit{Gleichlaeufigkeit} can be calculated as mean(glk(x), na.rm = TRUE).

References

Eckstein, D., Bauch J. (1969) Beitrag zur Rationalisierung eines dendrochronologischen Verfahrens und zur Analyse seiner Aussagesicherheit. Forstwissenschaftliches Centralblatt, 88(1):230{--}250.

Schweingruber, F. H. (1988) Tree rings: basics and applications of dendrochronology. Kluwer Academic Publishers, Dordrecht, Netherlands, 276 p.

Examples

Run this code
data(ca533)
ca533.glk <- glk(ca533)
mean(ca533.glk, na.rm = TRUE)

Run the code above in your browser using DataLab