Interactively detrend multiple tree-ring series by one of two methods, a
smoothing spline or a statistical model. This is a wrapper for
detrend.series.
i.detrend(rwl, y.name = names(rwl), nyrs = NULL, f = 0.5,
pos.slope = FALSE)An object of class c("rwi", "data.frame") (see
as.rwi) containing each detrended series according to
the method used as columns and rownames set to
colnames(y). These are typically years. The method
chosen for each series is recorded, named by series, in
attr(x, "dplR.detrend")$method. Plots are also
produced as the user chooses the detrending methods through keyboard
input.
a data.frame with series as columns and years as
rows such as that produced by read.rwl or
ca533
a character vector of length
ncol(rwl) that gives the ID of each
series. Defaults to the column names of rwl.
a number giving the rigidity of the smoothing spline,
defaults to 0.67 of series length if nyrs is
NULL.
a number between 0 and 1 giving the frequency response or wavelength cutoff. Defaults to 0.5.
a logical flag. Will allow for a positive
slope to be used in method "ModNegExp". If FALSE the
line will be horizontal.
Andy Bunn
This function allows a user to choose detrending curves based on plots
that are produced by detrend.series for which it is
essentially a wrapper. The user enters their choice of detrended
method via keyboard at a prompt for each ring width series in
rwl. See detrend.series for examples and
details on the detrending methods.
A series with no values at all is dropped, with a message naming it,
before any series is shown, and its name is dropped from
y.name too.
detrend.series