Learn R Programming

dplR (version 1.8.0)

plot.crs: Plotting crs Objects

Description

Plots objects returned from corr.rwl.seg.

Usage

# S3 method for crs
plot(x, ...)

Value

None. A plot is produced.

Arguments

x

An object of class "crs".

...

Additional arguments passed to plot

Author

Andy Bunn

Details

Each segment is drawn in blue if it correlates above the critical value, red if it does not, and green where it does not overlap the bin completely. If corr.rwl.seg was run with lag.max greater than 0, segments that correlate better at another lag (COFECHA’s B flag) are drawn in purple instead, whatever their correlation as dated.

See Also

corr.rwl.seg

Examples

Run this code
library(graphics)
data(co021)
foo <- corr.rwl.seg(co021, make.plot = FALSE)
plot(foo)

Run the code above in your browser using DataLab