data.frame of
ring-width series using the Becker algorithm. The pointer years are
computed with adjustable thresholds of relative radial growth
variation and number of series diplaying similar growth pattern
(i.e. positive or negative variations).pointer(rwl, rgv.thresh = 10, nseries.thresh = 75, round.decimals = 2)data.frame with ring-width series as columns and
years as rows such as that produced by read.rwl.numeric giving the minimum absolute
relative radial growth variation (in percentage) above which the
growth change from the year t-1 to t is considered as
significant. Must be > 0. Values > 100 are possible butnumeric giving the minimum percentage
of series displaying significant relative radial growth variations
of a same sign above which the year t is considered as
a pointer year. Positive significant variatinteger indicating the number of
decimal places to be used for outputs. This number must be
positive. Defaults to 2.data.frame containing the following columns (each row
corresponds to one position of the window):t of the time period covered by the series using the
Becker algorithm. This algorithm is based on, first, the calculation
of the individual relative radial growth variation by comparision of
ring-width of year t to that of year t-1 for
each series, and second, the inter-series comparision of both sign and
magnitude of these variations.
For example, if rgv.thresh and
nseries.thresh are set at 10 and 75 respectively, pointer
years will be defined as those years when at least 75% of the series
present an absolute relative radial growth variation higher than 10%.
Users unfamiliar with the Becker algorithm should refer to Becker et
al. (1994) and
skel.plot## Pointer years calculation on ring-width series. Returns a data.frame.
data(gp.rwl)
pointer(rwl=gp.rwl, rgv.thresh=10, nseries.thresh=75, round.decimals=2)Run the code above in your browser using DataLab