data.frame.read.ids(rwl, stc = c(3, 2, 3), ignore.site.case = FALSE,
ignore.case = FALSE, fix.typos = FALSE, typo.ratio = 5,
use.cor = TRUE)
autoread.ids(rwl, ignore.site.case = TRUE, ignore.case = "auto",
fix.typos = TRUE, typo.ratio = 5, use.cor = TRUE)stc[1]), the tree IDs
(stc[2]), and the logical flag. If TRUE and
stc is "auto", correlation clustering may be used for
determining the length of the tree and core parts. See Details.logical flag. If TRUE, the
function does not distinguish between upper case and lower case
letters in the site part of the series names.logical flag or "auto". If TRUE,
the function does not distinguish between upper case and lower case
letters in the tree / core part of the series names. The default in
read.ids is FALSElogical flag. If TRUE, the function
will try to detect and fix typing errors.numeric value larger than 1,
affecting the eagerness of the function to fix typing errors. The
default is 5. See Details.data.frame with column one named "tree" giving an
ID for each tree and column two named "core" giving
an ID for each core. The original series IDs are
copied from rwl as rownames. The order of the rows in the output
matches the order of the series in rwl. If more than one
site is detected, an additional third column named "site" will
contain a site ID. All columns have integral valued
numeric values.stc tells how each series separate into site,
tree, and core IDs. For instance a series code might be
"ABC011" indicating site "ABC", tree 1, core 1. If this
format is consistent then the stc mask would be
c(3, 2, 3) allowing up to three characters for the core
ID (i.e., pad to the right). If it is not possible to
define the scheme (and often it is not possible to machine read
IDs), then the output data.frame can be built
manually. See Value for format.
The function autoread.ids is a wrapper to read.ids with
stc="auto", i.e. automatic detection of the site / tree / core
scheme, and different default values of some parameters. In automatic
mode, the names in the same rwl can even follow different
site / tree / core schemes. As there are numerous possible encoding
schemes for naming measurement series, the function cannot always
produce the correct result.
With stc="auto", the site part can be one of the following.
ignore.caseto"auto"allows the function to try to guess when a case change in the middle
of a sequence of alphabets signifies a boundary between the site
part and the tree part.ignore.casemust be set to"auto"orFALSE.use.cor is
TRUE, number two if it is FALSE.
typo.ratiohas a
double meaning as it also defines what is meant by majority here: at
leasttypo.ratio / (typo.ratio + 1) *
n.tot, wheren.totis the number of names in the site.fix.typos is TRUE. The parameter
typo.ratio affects the eagerness to fix typos, i.e. the
number of counterexamples required to declare a typo. The following
main typo fixing mechanisms are implemented: [object Object],[object Object]
The function attempts to convert the tree and core substrings to
integral values. When this succeeds, the converted values are copied
to the output without modification. When non-integral substrings are
observed, each unique tree is assigned a unique integral value. The
same applies to cores within a tree, but there are some subtleties
with respect to the handling of duplicates. Substrings are sorted
before assigning the numeric IDs.
The order of columns in rwl, in most cases, does not
affect the tree and core IDs assigned to each series.rwi.stats, read.rwldata(ca533)
read.ids(ca533, stc = c(3, 2, 3))
autoread.ids(ca533)Run the code above in your browser using DataLab