| spag.plot | R Documentation |
Makes a spaghetti plot of tree-ring data.
spag.plot(rwl, zfac = 1, useRaster = FALSE, res = 150, ...)
rwl |
a |
zfac |
a multiplier for |
useRaster |
A |
res |
A |
... |
arguments to be passed to |
This makes a simple plot of each series in a tree-ring data set. Each
series is centered first by subtracting the column mean using
scale. The plot can be grossly tuned with
zfac which is a multiplier to rwl before
plotting and centering.
Ring-width indices (class "rwi", see as.rwi) are
centred on 1, or on 0 if they are differences, and not on their
means, so the grey line under each series is the value the indices
should sit at.
None. This function is invoked for its side effect, which is to produce a plot.
Andy Bunn. Patched and improved by Mikko Korpela.
seg.plot
library(utils)
data(co021)
plot(co021,plot.type = "spag")
spag.plot(co021, zfac = 2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.