strip.rwl(rwl, ids = NULL, verbose = FALSE, comp.plot = FALSE,
legacy.eps = FALSE)data.frame with column one named
"tree" giving a numeric ID for each tree and
column two named "core" giving a numeric ID
for ealogical flag, indicating if the EPS
calculated at each step and other details should be printed on the
console during the chronology stripping processlogical flag, indicating if a diagnostic plot
with year-wise stripped and unstripped EPS should be drawn
(see details below)logical flag, indicating if the EPS
will be calculated with rwi.stats (FALSE, the default)
or rwi.stats.legacy (TRUE)data.frame of raw tree-ring widths,
where series that do not contribute to an overall improvement in
EPS are left out.data.frame is
considered. In each iteration, the series (if any) whose reinsertion
increases EPS the most is reinserted. As a last step,
EPS is calculated for each year of the stripped and original
chronology including all series. If comp.plot is set to
TRUE, a diagnostic plot is shown for the year-wise comparison.When verbose output is chosen, the EPS values for all leave-one-out (or back-in) chronologies are reported. If discarding or re-inserting a single series leads to an improvement in EPS, this series is marked with an asterisk.
rwi.statsdata(anos1)
anos1.ids <- read.ids(anos1, stc = c(4, 3, 1))
strip.rwl(anos1, ids = anos1.ids, verbose = TRUE)Run the code above in your browser using DataLab