corr.series.seg(rwl,series,series.yrs=as.numeric(names(series)),
seg.length=50,bin.floor=100,n=NULL, prewhiten = TRUE, biweight=TRUE,
pcrit=0.05, make.plot = TRUE,...)data.frame with series as columns and years as rows
such as that produced by read.rwl.numeric vector. Usually a tree-ring series.numeric vector giving the years of series.
Defaults to as.numeric(names(series)).integer giving length of segments in years
(e.g., 20, 50, 100 years).integer giving the base for locating
the first segment (e.g.,.1600, 1700, 1800 AD). Typically 0, 10, 50, 100,
etc.NULL or an integer giving the filter length for the
hanning filter used for removal of low frequency
variation.logical flag. If TRUE each series is whitened using
ar.logical flag. If TRUE then a robust mean is calculated
using tbrm.ccf.logical flag indicating whether to make a plot.list containing matrices bins, moving.rho, and vectors
spearman.rho, p.val, and overall.bin.floor. Correlations are calculcated
for the first segment, then the second segment and so on. Correlations are
only calculated for segments with complete overlap with the master chronology.
A moving correlation with length equal to the segment length is also
calculated between the series and the master.
Each series (inlcuding those in the rwl object) is optionally detrended as the residuals
from a hanning filter with weight n. The filter is not applied
if n is NULL. Detrending can also be done via prewhitening where
the residuals of an ar model are added to each series
mean. This is the default. The master chronology is computed as the mean of
rwl object using tbrm if biweight=TRUE and rowMeans
if not. Note that detrending can change the length of the series. E.g., a
hanning filter will shorten the series on either end by
floor(n/2). The effects of detrending can be seen with
series.rwl.plot. The function is typically invoked to produce a
plot.corr.series.seg skel.plot series.rwl.plot ccf.series.rwldata(co021)
dat=co021
#create a missing ring by deleting a year of growth in a random series
flagged=dat$'641143'
flagged=c(NA,flagged[-325])
names(flagged)=rownames(dat)
dat$'641143'=NULL
seg.100=corr.series.seg(rwl=dat,series=flagged,seg.length=100,biweight=FALSE)Run the code above in your browser using DataLab