Interactively detrend a tree-ring series by one of three methods, a
smoothing spline, a linear model, or the mean. This is a wrapper for
detrend.series.
i.detrend.series(y, y.name = NULL, nyrs = NULL, f = 0.5,
pos.slope = FALSE)A vector containing the detrended series (y) according to
the method used with names set to colnames(y). These are
typically years. The name of the method chosen is attached as
attr(x, "method"). A plot is also produced and the user
chooses a method through keyboard input.
a numeric vector. Usually a tree-ring series.
an optional character vector to name the series
for plotting purposes.
a number giving the rigidity of the smoothing spline,
defaults to 0.67 of series length if nyrs is
NULL.
a number between 0 and 1 giving the frequency response or wavelength cutoff. Defaults to 0.5.
a logical flag. Will allow for a positive
slope to be used in method "ModNegExp". If FALSE the
line will be horizontal.
Andy Bunn. Patched and improved by Mikko Korpela.
This function allows a user to choose a detrending method based on a
plot that is produced by detrend.series for which it is
essentially a wrapper. The user enters their choice of detrended
method via keyboard at a prompt. See detrend.series for
examples and details on the detrending methods.
detrend.series