read.fh(fname)character vector giving the file name of the fh
file.data.frame with the series in columns and the years as rows. The
keycodes are the column names and the years are the row
names. Depending on metadata available in the input file, the
following attributes may be present in the data.frame:data.frame identifying the series. Always contains
columns "tree" and "core", may contain columns
"site", "radius", and "stemDisk". All
columns are numeric.data.frame containing pith offsets, formatted for
use in rcs.read.rwl