This makes a simple plot of each series in a tree-ring data set. Each
series is centered first by subtracting the column mean using
scale. The plot can be grossly tuned with
zfac which is a multiplier to rwl before
plotting and centering.
Ring-width indices (class "rwi", see as.rwi) are
centred on 1, or on 0 if they are differences, and not on their
means, so the grey line under each series is the value the indices
should sit at.