- rwl
a data.frame with series as columns and years as
rows such as that produced by read.rwl.
- series
a numeric vector of ring widths, e.g. a single column
from an rwl object.
- series.name
a character string giving a name for the
undated series. Defaults to "Unknown".
- min.overlap
a positive integer giving the minimum number of
years of overlap required between the series and the master
chronology at each search position. Defaults to 50.
- n
NULL or a positive integer giving the filter length
for the hanning filter used for removal of low
frequency variation prior to correlation. NULL skips the
filter.
- nyrs
NULL or a number greater than zero. If not
NULL, each series is divided by a smoothing spline with this
rigidity (see caps) to remove low-frequency variation,
as detrend does with method = "Spline". A value
of 1 or less is taken as a proportion of each series' length.
Unlike the hanning filter, the spline removes no years
from the ends of a series. Cannot be combined with n.
- prewhiten
logical flag. If TRUE (the default) each
series is whitened using ar prior to correlation.
- ar.order.max
NULL or a positive integer giving the
maximum order of the ar model used to prewhiten.
Prewhitening removes as many years from the start of each series as
the order of the model. If NULL, the order is chosen by AIC
up to the ar default, which on long series can be 20
or more. Requires prewhiten = TRUE.
- biweight
logical flag. If TRUE (the default) a robust
mean is used when building the master chronology via
tbrm.
- method
the correlation coefficient to use. One of
"spearman" (default), "pearson", or "kendall".
See cor.test.
- make.plot
logical flag. If TRUE (the default) a
two-panel plot is produced showing the segments and the correlation
surface. See Details.
- return.rwl
logical flag. If TRUE (the default) a
"floater" list object is returned. If FALSE only the
correlation statistics data.frame is returned.
- verbose
logical flag. If TRUE (the default) a brief
summary is printed to the console.
- x
a "floater" object produced by
xdate.floater.
- ...
additional arguments — currently ignored.